@@ -1,3 +1,6 @@
 package DBICTest::Schema::_skip_load_external::Foo;
+use strict;
+use warnings;
+
 our $skip_me = "bad mojo";
 1;
