@@ -1,4 +1,6 @@
 package TestComponentFQN;
+use strict;
+use warnings;
 
 sub testcomponent_fqn { 'TestComponentFQN works' }
 
